@@ -33,9 +33,10 @@
 #  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT KCOMPLETION_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCOMPLETION_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCOMPLETION_NO_DEPRECATED
+#    define KCOMPLETION_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
